@@ -437,37 +437,26 @@ spacing = "                               "
 
 
 def main(args=None):
-    parser = argparse.ArgumentParser(
-        description="Spotify and Tunefind Bridge Simple CLI"
-    )
+    parser = argparse.ArgumentParser(description="Spotify and Tunefind Bridge Simple CLI")
     subparsers = parser.add_subparsers()
 
-    parser_spot_init = subparsers.add_parser(
-        "spot_init", help="Initialize Spotify & setup client credentials"
-    )
+    parser_spot_init = subparsers.add_parser("spot_init", help="Initialize Spotify & setup client credentials")
     parser_spot_init.set_defaults(func=spot_init_from_parser)
 
-    parser_spot_auth = subparsers.add_parser(
-        "spot_auth", help="Authorize Spotify Client and get access and refresh tokens"
-    )
+    parser_spot_auth = subparsers.add_parser("spot_auth", help="Authorize Spotify Client and get access and refresh tokens")
     optional_named = parser_spot_auth.add_argument_group("Optional named arguments")
-    optional_named.add_argument(
-        "--overwrite", help="Type yes to overwrite existing", default=None
-    )
+    optional_named.add_argument("--overwrite", help="Type yes to overwrite existing", default=None)
     parser_spot_auth.set_defaults(func=spot_auth_from_parser)
 
-    parser_spot_refresh = subparsers.add_parser(
-        "spot_refresh", help="Refresh spotify token"
-    )
+    parser_spot_refresh = subparsers.add_parser("spot_refresh", help="Refresh spotify token")
     parser_spot_refresh.set_defaults(func=spot_refresh_from_parser)
 
-    parser_spot_tune = subparsers.add_parser(
-        "spot_tune", help="Tunefind playlist to spotify playlist"
-    )
-    parser_spot_tune.add_argument("--url", help="Tunefind series url")
-    parser_spot_tune.add_argument("--name", help="Spotify playlist name")
-    parser_spot_tune.add_argument("--desc", help="Spotify Playlist Description")
-    parser_spot_tune.add_argument("--playlist", help="public or private")
+    parser_spot_tune = subparsers.add_parser("spot_tune", help="Tunefind playlist to spotify playlist")
+    required_named = parser_spot_tune.add_argument_group('Required named arguments.')
+    required_named.add_argument("--url", help="Tunefind series url", required=True)
+    required_named.add_argument("--name", help="Spotify playlist name", required=True)
+    required_named.add_argument("--desc", help="Spotify Playlist Description", required=True)
+    required_named.add_argument("--playlist", help="public or private", required=True)
     parser_spot_tune.set_defaults(func=spot_tune_from_parser)
     args = parser.parse_args()
 
